/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::DecayHeatModel

Group
    grpLagrangianIntermediateDecayHeatSubModels

Description
    Templated heat transfer model class

SourceFiles
    DecayHeatModel.C
    DecayHeatModelNew.C

\*---------------------------------------------------------------------------*/

#ifndef DecayHeatModel_H
#define DecayHeatModel_H

#include "IOdictionary.H"
#include "autoPtr.H"
#include "runTimeSelectionTables.H"
#include "CloudSubModelBase.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                       Class DecayHeatModel Declaration
\*---------------------------------------------------------------------------*/

template<class CloudType>
class DecayHeatModel
:
    public CloudSubModelBase<CloudType>
{

public:

    //- Runtime type information
    TypeName("decayHeatModel");

    //- Declare runtime constructor selection table
    declareRunTimeSelectionTable
    (
        autoPtr,
        DecayHeatModel,
        dictionary,
        (
            const dictionary& dict,
            CloudType& owner
        ),
        (dict, owner)
    );


    // Constructors

        //- Construct null from owner
        DecayHeatModel(CloudType& owner);

        //- Construct from dictionary
        DecayHeatModel
        (
            const dictionary& dict,
            CloudType& owner,
            const word& type
        );

         //- Construct copy
         DecayHeatModel(const DecayHeatModel<CloudType>& dhm);

        //- Construct and return a clone
        virtual autoPtr<DecayHeatModel<CloudType>> clone() const = 0;


    //- Destructor
    virtual ~DecayHeatModel();


    //- Selector
    static autoPtr<DecayHeatModel<CloudType>> New
    (
        const dictionary& dict,
        CloudType& owner
    );


    // Member Functions


        // Evaluation
           
            //- Retrun decay Power
            virtual scalar decayPower() const = 0;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#define makeDecayHeatModel(CloudType)                                       \
                                                                               \
    typedef Foam::CloudType::thermoCloudType thermoCloudType;                  \
    defineNamedTemplateTypeNameAndDebug                                        \
    (                                                                          \
        Foam::DecayHeatModel<thermoCloudType>,                              \
        0                                                                      \
    );                                                                         \
    namespace Foam                                                             \
    {                                                                          \
        defineTemplateRunTimeSelectionTable                                    \
        (                                                                      \
            DecayHeatModel<thermoCloudType>,                                \
            dictionary                                                         \
        );                                                                     \
    }


#define makeDecayHeatModelType(SS, CloudType)                               \
                                                                               \
    typedef Foam::CloudType::thermoCloudType thermoCloudType;                  \
    defineNamedTemplateTypeNameAndDebug(Foam::SS<thermoCloudType>, 0);         \
                                                                               \
    Foam::DecayHeatModel<thermoCloudType>::                                 \
        adddictionaryConstructorToTable<Foam::SS<thermoCloudType>>             \
            add##SS##CloudType##thermoCloudType##ConstructorToTable_;


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#ifdef NoRepository
    #include "DecayHeatModel.C"
#endif

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
