/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::NoDecayHeat

Group
    grpLagrangianIntermediateDecayHeatSubModels

Description
    Dummy decay heat model for 'none'

\*---------------------------------------------------------------------------*/

#ifndef NoDecayHeat_H
#define NoDecayHeat_H

#include "DecayHeatModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                       Class NoDecayHeat Declaration
\*---------------------------------------------------------------------------*/

template<class CloudType>
class NoDecayHeat
:
    public DecayHeatModel<CloudType>
{
public:

    //- Runtime type information
    TypeName("none");


    // Constructors

        //- Construct from dictionary
        NoDecayHeat(const dictionary&, CloudType& owner);

        //- Construct copy
        NoDecayHeat(const NoDecayHeat<CloudType>& dhm);

        //- Construct and return a clone
        virtual autoPtr<DecayHeatModel<CloudType>> clone() const
        {
            return autoPtr<DecayHeatModel<CloudType>>
            (
                new NoDecayHeat<CloudType>(*this)
            );
        }


    //- Destructor
    virtual ~NoDecayHeat();


    // Member Functions

        //- Flag to indicate whether model activates heat transfer model
        virtual bool active() const;

       
        //- decay Power
        virtual scalar decayPower() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#ifdef NoRepository
    #include "NoDecayHeat.C"
#endif

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
