/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 2011-2016 OpenFOAM Foundation
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

Class
    Foam::constantDecayHeat

Group
    grpLagrangianIntermediateDecayHeatSubModels

Description
    Dummy decay heat model for 'none'

\*---------------------------------------------------------------------------*/

#ifndef constantDecayHeat_H
#define constantDecayHeat_H

#include "DecayHeatModel.H"

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

namespace Foam
{

/*---------------------------------------------------------------------------*\
                       Class constantDecayHeat Declaration
\*---------------------------------------------------------------------------*/

template<class CloudType>
class constantDecayHeat
:
    public DecayHeatModel<CloudType>
{
    //private data
   
    scalar decayPower_;
    
public:

    //- Runtime type information
    TypeName("constantDecayHeat");


    // Constructors

        //- Construct from dictionary
        constantDecayHeat(const dictionary& dict, CloudType& cloud);

        //- Construct copy
        constantDecayHeat(const constantDecayHeat<CloudType>& dhm);

        //- Construct and return a clone
        virtual autoPtr<DecayHeatModel<CloudType>> clone() const
        {
            return autoPtr<DecayHeatModel<CloudType>>
            (
                new constantDecayHeat<CloudType>(*this)
            );
        }


    //- Destructor
    virtual ~constantDecayHeat();


    // Member Functions

        //- Flag to indicate whether model activates heat transfer model
        virtual bool active() const;

       
        virtual scalar decayPower() const;
};


// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

} // End namespace Foam

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#ifdef NoRepository
    #include "constantDecayHeat.C"
#endif

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //

#endif

// ************************************************************************* //
